@@ -35,8 +35,6 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <libgnomeui/gnome-icon-theme.h>
-#include <libgnomeui/gnome-icon-lookup.h>
 #include "quick-button.h"
 
 #define DEFAULT_OFFSET      2
@@ -263,20 +261,22 @@ missing_pixbuf (int size)
  
 
 static GdkPixbuf *
-get_missing (GnomeIconTheme *theme, 
+get_missing (GtkIconTheme    *theme, 
 	     int             preffered_size)
 {
-	char *filename = NULL;
-
-	filename = gnome_icon_theme_lookup_icon (theme,
-						 "gnome-unknown",
-						 preffered_size,
-						 NULL,
-						 NULL);
+	GtkIconInfo *icon_info;
+	const char  *filename = NULL;
+	
+	icon_info = gtk_icon_theme_lookup_icon (theme,	
+						"gnome-unknown",
+						preffered_size,
+						0);
 
+	filename = gtk_icon_info_get_filename (icon_info);
+	gtk_icon_info_free (icon_info);
 	if (filename == NULL)
 		return missing_pixbuf (preffered_size);
-		
+
 	return gdk_pixbuf_new_from_file (filename, NULL);
 }
 
@@ -444,16 +444,13 @@ quick_button_expose (GtkWidget         *widget,
 	area = event->area;
 	
 	if (gdk_rectangle_intersect (&area, &widget->allocation, &area) &&
-	    gdk_rectangle_intersect (&image_bound, &area, &image_bound))  
-		gdk_pixbuf_render_to_drawable_alpha (pixbuf,
-						     widget->window,
-						     image_bound.x - x, image_bound.y - y,
-						     image_bound.x, image_bound.y,
-						     image_bound.width, image_bound.height,
-						     GDK_PIXBUF_ALPHA_FULL,
-						     128,
-						     GDK_RGB_DITHER_NORMAL,
-						     0, 0);
+	    gdk_rectangle_intersect (&image_bound, &area, &image_bound))
+		gdk_draw_pixbuf (widget->window, NULL, pixbuf, 
+				 image_bound.x - x, image_bound.y - y,
+				 image_bound.x, image_bound.y,
+				 image_bound.width, image_bound.height,
+				 GDK_RGB_DITHER_NORMAL,
+				 0, 0);
 	
 	if (quick_button->dnd_highlight) 
 		gdk_draw_rectangle (widget->window, 
@@ -663,7 +660,7 @@ GtkWidget *
 quick_button_new (const char     *icon_path,
 		  int             size,
 		  const char     *text,
-		  GnomeIconTheme *icon_theme)
+		  GtkIconTheme   *icon_theme)
 {
 	QuickButton *button;
 
